pub struct LogcatOptions {
pub expr: Option<String>,
pub dump: bool,
pub filename: Option<String>,
pub tags: Option<Vec<LogcatTag>>,
pub format: Option<String>,
pub since: Option<DateTime<Local>>,
pub pid: Option<i32>,
pub timeout: Option<Duration>,
}Fields
expr: Option<String>-e Only prints lines where the log message matches expr, where expr is a regular expression.
dump: bool-d Dumps the log to the screen and exits.
filename: Option<String>-f filename Writes log message output to filename. The default is stdout.
-s Equivalent to the filter expression ‘*:S’, which sets priority for all tags to silent and is used to precede a list of filter expressions that add content.
format: Option<String>-v format Sets the output format for log messages. The default is the thread time format
since: Option<DateTime<Local>>-t ‘time’ Prints the most recent lines since the specified time. This option includes -d functionality. See the -P option for information about quoting parameters with embedded spaces.
pid: Option<i32>timeout: Option<Duration>Trait Implementations
Sourceimpl Clone for LogcatOptions
impl Clone for LogcatOptions
Sourcefn clone(&self) -> LogcatOptions
fn clone(&self) -> LogcatOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogcatOptions
impl Debug for LogcatOptions
Sourceimpl Default for LogcatOptions
impl Default for LogcatOptions
Sourceimpl IntoIterator for LogcatOptions
impl IntoIterator for LogcatOptions
Sourceimpl PartialEq for LogcatOptions
impl PartialEq for LogcatOptions
impl Eq for LogcatOptions
impl StructuralPartialEq for LogcatOptions